import styles from './ProfileItem.module.css';
import { Component } from "solid-js";
import { showDialog, showMessageDialog } from "../state";
import { errorToString } from "../util";
import { BsTrash } from 'solid-icons/bs';
import { Group, Profile, api } from '../api';

export interface ProfileItemProps {
	group: Group,
	profile: Profile,
	onDelete: (p: Profile) => void
}

const ProfileItem: Component<ProfileItemProps> = (props) => {

	const deleteProfile = async () => {
		showDialog({
			title: 'Remove profile',
			text: 'Do you want to remove this profile?',
			buttons: [
				{
					name: 'Remove',
					type: 'danger',
					closeOnClick: true,
					action: async () => {
						try {
							await api().removeProfileFromGroup(props.group.id, props.profile.id);
							props.onDelete(props.profile);
						} catch (e) {
							showMessageDialog('Failed to remove profile', errorToString(e));
						}
					}
				},
				{
					name: 'Cancel',
					closeOnClick: true,
					action: () => { }
				}
			]
		});
	};

	return (
		<div class={styles.profile}>
			<div class={styles.profileDetails}>
				<div class={styles.profileName}>
					<span innerText={props.profile.name} />
				</div>
				<div>
					<button onClick={deleteProfile}><BsTrash /></button>
				</div>
			</div>
		</div >
	)
}

export default ProfileItem;
