export function errorToString(e: any): string { // eslint-disable-line @typescript-eslint/no-explicit-any
	if (typeof e == 'string') {
		return e;
	} else if (e.toString) {
		return e.toString() as string;
	} else {
		return 'Unknown error';
	}
}

export function normalize(text: string, maxLength: number, oneLine: boolean) {
	if (oneLine) text = text.replaceAll('\n', '');
	text = text.substring(0, maxLength);
	return text;
}

export function normalizeQuantity(text: string) {
	let quantity = parseInt(text);

	if (isNaN(quantity) || quantity < 0) {
		return 1;
	}

	return quantity;
}

function clamp(value: number, min: number, max: number) {
	return Math.min(Math.max(value, min), max);
};

export function normalizeRating(text: string) {
	let rating = parseInt(text);

	if (isNaN(rating)) {
		return 1;
	}

	return clamp(rating, 0, 5);
}

export function _arrayBufferToBase64(buffer: ArrayBuffer) {
	var binary = '';
	var bytes = new Uint8Array(buffer);
	var len = bytes.byteLength;
	for (var i = 0; i < len; i++) {
		binary += String.fromCharCode(bytes[i]);
	}
	return window.btoa(binary);
}

export const b64toBlob = (b64Data: string, contentType = '', sliceSize = 512) => {
	const byteCharacters = atob(b64Data);
	const byteArrays = [];

	for (let offset = 0; offset < byteCharacters.length; offset += sliceSize) {
		const slice = byteCharacters.slice(offset, offset + sliceSize);

		const byteNumbers = new Array(slice.length);
		for (let i = 0; i < slice.length; i++) {
			byteNumbers[i] = slice.charCodeAt(i);
		}

		const byteArray = new Uint8Array(byteNumbers);
		byteArrays.push(byteArray);
	}

	const blob = new Blob(byteArrays, { type: contentType });
	return blob;
}
